@@ -2,11 +2,10 @@ import errno
 import os
 import re
 import shutil
-import string
 import zipfile
 
 from distutils import log
-from distutils.errors import DistutilsPlatformError, DistutilsInternalError, DistutilsSetupError
+from distutils.errors import DistutilsPlatformError, DistutilsInternalError, DistutilsSetupError, DistutilsOptionError
 from setuptools import Command
 from subprocess import Popen, PIPE
 
@@ -34,13 +33,31 @@ def validate_lambda_package(dist, attr, value):
 class LDist(Command):
 
     description = 'build a AWS Lambda compatible distribution'
-    user_options = []
+    user_options = [
+        ('include-version=', None, 'Include the version number on the lambda distribution name')
+    ]
 
     def initialize_options(self):
-        pass
+        """Set default values for options."""
+        # Each user option must be listed here with their default value.
+        setattr(self, 'include_version', None)
 
     def finalize_options(self):
-        pass
+        inc_ver = getattr(self, 'include_version')
+        if inc_ver is None or \
+                inc_ver == '' or \
+                inc_ver == 'True' or \
+                inc_ver == 'true' or \
+                inc_ver == 'Yes' or \
+                inc_ver == 'yes':
+            setattr(self, 'include_version', True)
+        elif inc_ver == 'False' or \
+                inc_ver == 'false' or \
+                inc_ver == 'No' or \
+                inc_ver == 'no':
+            setattr(self, 'include_version', False)
+        else:
+            raise DistutilsOptionError('include-version must be True, true, Yes, yes, False, false, No, no or absent')
 
     def run(self):
         # We must create a distribution to install first
@@ -62,7 +79,9 @@ class LDist(Command):
         self._build_lambda_package()
 
     def _build_lambda_package(self):
-        dist_name = '{}-{}.zip'.format(self.distribution.get_name(), self.distribution.get_version())
+        dist_name = '{}-{}.zip'.format(self.distribution.get_name(), self.distribution.get_version()) \
+            if getattr(self, 'include_version') \
+            else '{}.zip'.format(self.distribution.get_name())
         dist_path = os.path.join(self._dist_dir, dist_name)
         if os.path.exists(dist_path):
             os.remove(dist_path)
@@ -87,7 +106,7 @@ class LDist(Command):
         lambda_function = getattr(self.distribution, 'lambda_function', None)
         if not lambda_function:
             return
-        components = string.split(lambda_function, ':')
+        components = lambda_function.split(':')
         module = components[0]
         function = components[1]
         function_lines = [
